lorax is a web service for calculating multiple sequence alignments
and phylogenetic trees for genes and gene families.  Under the hood, lorax uses
`FastTree`_ or `RAxML`_ to calculate trees, `HMMER`_ to do multiple sequence
alignments, `RQ`_ to queue long calculations, and `Flask`_ to serve up results.


.. image:: https://img.shields.io/pypi/v/lorax.svg
   :target: https://pypi.python.org/pypi/lorax
   :alt: PyPI python package

.. image:: https://img.shields.io/github/commits-since/LegumeFederation/lorax/0.92.svg
   :target: https://github.com/LegumeFederation/lorax
   :alt: GitHub repository

.. image:: https://secure.travis-ci.org/LegumeFederation/lorax.png
   :target:  https://travis-ci.org/LegumeFederation/lorax
   :alt: Travis continuous integration testing

.. image:: https://readthedocs.org/projects/lorax/badge/?version=latest
   :target: https://lorax.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://landscape.io/github/LegumeFederation/lorax/master/landscape.svg?style=flat
   :target: https://landscape.io/github/LegumeFederation/lorax
   :alt: landscape.io status

.. image:: https://api.codacy.com/project/badge/Grade/2ebc65ca90f74dc7a9238c202f327981
   :target: https://www.codacy.com/app/joelb123/lorax?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=LegumeFederation/lorax&amp;utm_campaign=Badge_Grade
   :alt: Codacy.io grade

.. image:: https://codecov.io/gh/LegumeFederation/lorax/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/LegumeFederation/lorax
  :alt: Codecov.io test coverage

:Homepage: `Lorax GitHub`_
:Download: `Lorax PyPI`_
:Documentation: `Lorax ReadTheDocs`_
:Issue Tracker: `Lorax Issues`_
:License: `BSD 3-Clause License`_

.. _Lorax GitHub: https://github.com/LegumeFederation/lorax
.. _BSD 3-Clause License: https://github.com/LegumeFederation/lorax/blob/master/LICENSE.txt
.. _Lorax ReadTheDocs: https://lorax.readthedocs.io/en/latest
.. _Lorax PyPI: https://pypi.python.org/pypi/lorax
.. _Flask: http://flask.pocoo.org/
.. _RQ: https://github.com/nvie/rq
.. _HMMER: http://hmmer.org
.. _RAxML: https://github.com/stamatak/standard-RAxML
.. _FastTree: http://www.microbesonline.org/fasttree
.. _Lorax Issues: https://github.com/LegumeFederation/lorax/issues



